@@ -16,9 +16,11 @@
 #'    caps <- wfs$getCapabilities()
 #'    
 #'    #find feature type
-#'    ft <- caps$findFeatureTypeByName("mylayer", exact = TRUE)
-#'    data <- ft$getFeatures()
-#'    data_with_filter <- ft$getFeatures(cql_filter = "somefilter")
+#'    ft <- caps$findFeatureTypeByName("mylayer")
+#'    if(length(ft)>0){
+#'      data <- ft$getFeatures()
+#'      data_with_filter <- ft$getFeatures(cql_filter = "somefilter")
+#'    }
 #'    
 #'    #Advanced examples at https://github.com/eblondel/ows4R/wiki#wfs
 #' }
@@ -78,9 +80,11 @@ WFSClient <- R6Class("WFSClient",
      describeFeatureType = function(typeName){
        self$INFO(sprintf("Fetching featureType description for '%s' ...", typeName))
        describeFeatureType <- NULL
-       ft <- self$capabilities$findFeatureTypeByName(typeName, exact = TRUE)
+       ft <- self$capabilities$findFeatureTypeByName(typeName)
        if(is(ft, "WFSFeatureType")){
          describeFeatureType <- ft$getDescription()
+       }else if(is(ft, "list")){
+          describeFeatureType <- ft[[1]]$getDescription()
        }
        return(describeFeatureType)
      },
@@ -89,9 +93,11 @@ WFSClient <- R6Class("WFSClient",
      getFeatures = function(typeName, ...){
        self$INFO(sprintf("Fetching features for '%s' ...", typeName))
        features <- NULL
-       ft <- self$capabilities$findFeatureTypeByName(typeName, exact = TRUE)
+       ft <- self$capabilities$findFeatureTypeByName(typeName)
        if(is(ft,"WFSFeatureType")){
          features <- ft$getFeatures(...)
+       }else if(is(ft, "list")){
+          features <- ft[[1]]$getFeatures(...)
        }
        return(features)
      },
